*[WFO]: Workflow Orchestrator
*[YAML]: YAML Ain't Markup Language™
*[SURF]: The national research and education network of the Netherlands.
*[ESnet]: The Energy Sciences Network
*[GÉANT]: The pan-European data network for the research and education community.
*[NREN]: National Research and Education Network
